Coverage for src/tests/test_starts_with.py: 100%

1 import remedapy as R

2

3

4 class TestStartsWith:

5 def test_data_first(self):

6 # R.starts_with(data, prefix);

7 assert R.starts_with('hello world', 'hello')

8 assert not R.starts_with('hello world', 'world')

9

10 def test_data_last(self):

11 # R.starts_with(prefix)(data);

12 assert R.pipe('hello world', R.starts_with('hello'))

13 assert not R.pipe('hello world', R.starts_with('world'))